
void _efl_datetime_manager_value_set(Eo *obj, Efl_Datetime_Manager_Data *pd, Efl_Time newtime);

EAPI EAPI_WEAK EFL_VOID_FUNC_BODYV(efl_datetime_manager_value_set, EFL_FUNC_CALL(newtime), Efl_Time newtime);

Efl_Time _efl_datetime_manager_value_get(const Eo *obj, Efl_Datetime_Manager_Data *pd);

EAPI EAPI_WEAK EFL_FUNC_BODY_CONST(efl_datetime_manager_value_get, Efl_Time, ((Efl_Time){0}));

void _efl_datetime_manager_format_set(Eo *obj, Efl_Datetime_Manager_Data *pd, const char *fmt);


static Eina_Error
__eolian_efl_datetime_manager_format_set_reflect(Eo *obj, Eina_Value val)
{
   Eina_Error r = 0;   const char *cval;
   if (!eina_value_string_convert(&val, &cval))
      {
         r = EINA_ERROR_VALUE_FAILED;
         goto end;
      }
   efl_datetime_manager_format_set(obj, cval);
 end:
   eina_value_flush(&val);
   return r;
}

EAPI EAPI_WEAK EFL_VOID_FUNC_BODYV(efl_datetime_manager_format_set, EFL_FUNC_CALL(fmt), const char *fmt);

const char *_efl_datetime_manager_format_get(const Eo *obj, Efl_Datetime_Manager_Data *pd);


static Eina_Value
__eolian_efl_datetime_manager_format_get_reflect(const Eo *obj)
{
   const char *val = efl_datetime_manager_format_get(obj);
   return eina_value_string_init(val);
}

EAPI EAPI_WEAK EFL_FUNC_BODY_CONST(efl_datetime_manager_format_get, const char *, NULL);

const char *_efl_datetime_manager_string_get(const Eo *obj, Efl_Datetime_Manager_Data *pd, const char *fmt);

EAPI EAPI_WEAK EFL_FUNC_BODYV_CONST(efl_datetime_manager_string_get, const char *, NULL, EFL_FUNC_CALL(fmt), const char *fmt);

Efl_Object *_efl_datetime_manager_efl_object_constructor(Eo *obj, Efl_Datetime_Manager_Data *pd);


void _efl_datetime_manager_efl_object_destructor(Eo *obj, Efl_Datetime_Manager_Data *pd);


static Eina_Bool
_efl_datetime_manager_class_initializer(Efl_Class *klass)
{
   const Efl_Object_Ops *opsp = NULL;

   const Efl_Object_Property_Reflection_Ops *ropsp = NULL;

#ifndef EFL_DATETIME_MANAGER_EXTRA_OPS
#define EFL_DATETIME_MANAGER_EXTRA_OPS
#endif

   EFL_OPS_DEFINE(ops,
      EFL_OBJECT_OP_FUNC(efl_datetime_manager_value_set, _efl_datetime_manager_value_set),
      EFL_OBJECT_OP_FUNC(efl_datetime_manager_value_get, _efl_datetime_manager_value_get),
      EFL_OBJECT_OP_FUNC(efl_datetime_manager_format_set, _efl_datetime_manager_format_set),
      EFL_OBJECT_OP_FUNC(efl_datetime_manager_format_get, _efl_datetime_manager_format_get),
      EFL_OBJECT_OP_FUNC(efl_datetime_manager_string_get, _efl_datetime_manager_string_get),
      EFL_OBJECT_OP_FUNC(efl_constructor, _efl_datetime_manager_efl_object_constructor),
      EFL_OBJECT_OP_FUNC(efl_destructor, _efl_datetime_manager_efl_object_destructor),
      EFL_DATETIME_MANAGER_EXTRA_OPS
   );
   opsp = &ops;

   static const Efl_Object_Property_Reflection refl_table[] = {
      {"format", __eolian_efl_datetime_manager_format_set_reflect, __eolian_efl_datetime_manager_format_get_reflect},
   };
   static const Efl_Object_Property_Reflection_Ops rops = {
      refl_table, EINA_C_ARRAY_LENGTH(refl_table)
   };
   ropsp = &rops;

   return efl_class_functions_set(klass, opsp, ropsp);
}

static const Efl_Class_Description _efl_datetime_manager_class_desc = {
   EO_VERSION,
   "Efl.Datetime.Manager",
   EFL_CLASS_TYPE_REGULAR,
   sizeof(Efl_Datetime_Manager_Data),
   _efl_datetime_manager_class_initializer,
   NULL,
   NULL
};

EFL_DEFINE_CLASS(efl_datetime_manager_class_get, &_efl_datetime_manager_class_desc, EFL_OBJECT_CLASS, NULL);
